<?php
declare(strict_types = 1);

return [
    'authorName' => 'Condé Nast',
    'authorUrl' => 'https://twitter.com/wired',
    'cms' => null,
    'code' => null,
    'description' => 'We bring you the future as it happens. From the latest in science and technology to the big stories in business and culture, we\'ve got you covered.',
    'favicon' => 'https://www.wired.com/verso/static/wired-us/assets/favicon.ico',
    'feeds' => [
        'https://www.wired.com/feed/rss'
    ],
    'icon' => 'https://www.wired.com/verso/static/wired-us/assets/favicon.ico',
    'image' => 'https://media.wired.com/photos/615e2b8ce78a8cd913bbaa76/16:9/w_1280,c_limit/wired_bug.jpg',
    'keywords' => [],
    'language' => 'en-US',
    'languages' => [],
    'license' => 'Copyright (c) Condé Nast 2025',
    'providerName' => 'WIRED',
    'providerUrl' => 'https://www.wired.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'WIRED - The Latest in Technology, Science, Culture and Business',
    'url' => 'https://www.wired.com/?p=2064839',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@type' => 'Organization',
        'name' => 'WIRED',
        'logo' => [
            '@type' => 'ImageObject',
            'url' => 'https://www.wired.com/verso/static/wired-us/assets/newsletter-signup-hub.jpg',
            'width' => '500px',
            'height' => '100px'
        ],
        'url' => 'https://www.wired.com'
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'https://schema.org',
            '@type' => 'Organization',
            'name' => 'WIRED',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wired.com/verso/static/wired-us/assets/newsletter-signup-hub.jpg',
                'width' => '500px',
                'height' => '100px'
            ],
            'url' => 'https://www.wired.com'
        ],
        [
            '@context' => 'https://schema.org',
            '@type' => 'WebSite',
            'url' => 'https://www.wired.com',
            'name' => 'WIRED',
            'headline' => 'WIRED - The Latest in Technology, Science, Culture and Business',
            'potentialAction' => [
                '@type' => 'SearchAction',
                'target' => 'https://www.wired.com/search?q={search_term_string}',
                'query-input' => 'required name=search_term_string'
            ]
        ],
        [
            '@context' => 'https://schema.org',
            '@type' => 'ItemList',
            'itemListElement' => [
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Sam Altman Says the GPT-5 Haters Got It All Wrong',
                    'url' => 'https://www.wired.com/story/sam-altman-says-the-gpt-5-haters-got-it-all-wrong/',
                    'position' => 1
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'ICE Wants to Build Out a 24/7 Social Media Surveillance Team',
                    'url' => 'https://www.wired.com/story/ice-social-media-surveillance-24-7-contract/',
                    'position' => 2
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'At a Conspiracy Conference in Rural Ireland, Charlie Kirk Was the Star',
                    'url' => 'https://www.wired.com/story/conspiracy-conference-rural-ireland-charlie-kirk-quantum-clones/',
                    'position' => 3
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Government Workers Say Their Out-of-Office Replies Were Forcibly Changed to Blame Democrats for Shutdown',
                    'url' => 'https://www.wired.com/story/government-workers-say-their-out-of-office-replies-were-forcibly-changed-to-blame-democrats-for-shutdown/',
                    'position' => 4
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Inside the Contentious World of Luigi Mangione Supporters',
                    'url' => 'https://www.wired.com/story/inside-the-contentious-world-of-luigi-mangione-supporters/',
                    'position' => 5
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Why Are Car Software Updates Still So Bad?',
                    'url' => 'https://www.wired.com/story/why-are-car-software-updates-still-so-bad/',
                    'position' => 6
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Watch Our Livestream Replay: Tech Went All In on Trump. Now What?',
                    'url' => 'https://www.wired.com/story/livestream-tech-went-all-in-on-trump-now-what/',
                    'position' => 7
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Gear News of the Week: Adobe Premiere Lands on iPhone, and Nothing Lets You Design Your Own Widgets',
                    'url' => 'https://www.wired.com/story/gear-news-of-the-week-adobe-premiere-lands-on-iphone-and-nothing-lets-you-design-your-own-widgets/',
                    'position' => 8
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'The Vision Pro Was an Expensive Misstep. Now Apple Has to Catch Up With Smart Glasses',
                    'url' => 'https://www.wired.com/story/the-vision-pro-was-an-expensive-misstep-now-apple-has-to-catch-up-with-smart-glasses/',
                    'position' => 9
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Lenovo’s Streamlined Gaming Handheld Is $120 Off',
                    'url' => 'https://www.wired.com/story/legion-go-s-deal-1025/',
                    'position' => 10
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Bad Bunny Has MAGA All Worked Up',
                    'url' => 'https://www.wired.com/story/bad-bunny-has-maga-all-worked-up/',
                    'position' => 11
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'China Is Leading the World in the Clean Energy Transition. Here\'s What That Looks Like',
                    'url' => 'https://www.wired.com/story/china-clean-energy-un-climate-summit-goals/',
                    'position' => 12
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'China Rolls Out Its First Talent Visa as the US Retreats on H-1Bs',
                    'url' => 'https://www.wired.com/story/china-talent-immigration-visa-h1-b-policy/',
                    'position' => 13
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Chatbots Play With Your Emotions to Avoid Saying Goodbye',
                    'url' => 'https://www.wired.com/story/chatbots-play-with-emotions-to-avoid-saying-goodbye/',
                    'position' => 14
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'The Post–Chuck Schumer Era',
                    'url' => 'https://www.wired.com/story/chuck-schumer-government-shutdown/',
                    'position' => 15
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'OpenAI Is Preparing to Launch a Social App for AI-Generated Videos',
                    'url' => 'https://www.wired.com/story/openai-launches-sora-2-tiktok-like-app/',
                    'position' => 16
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Broadcast TV Is a \'Melting Ice Cube.’ Kimmel Just Turned Up the Heat',
                    'url' => 'https://www.wired.com/story/broadcast-tv-fcc-carr-kimmel/',
                    'position' => 17
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'The Trump Administration Is Coming for Nonprofits. They\'re Getting Ready',
                    'url' => 'https://www.wired.com/story/the-trump-administration-is-coming-for-nonprofits-theyre-getting-ready/',
                    'position' => 18
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Federal Workers Are Being Told to Blame Democrats for the Shutdown',
                    'url' => 'https://www.wired.com/story/government-employees-out-of-office-email-replies/',
                    'position' => 19
                ],
                [
                    '@context' => 'https://schema.org',
                    '@type' => 'ListItem',
                    'name' => 'Armed Guards and Muscle Milk: Senate Investigation Reveals DOGE Takeover Details',
                    'url' => 'https://www.wired.com/story/armed-guards-muscle-milk-senate-investigation-doge-takeover-details/',
                    'position' => 20
                ]
            ],
            'numberOfItems' => 20,
            'mainEntityOfPage' => [
                '@context' => 'https://schema.org',
                '@type' => 'CollectionPage',
                '@id' => 'https://www.wired.com'
            ]
        ]
    ]
];
