<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Not a Meetup member yet? Log in and find groups that host online or in person events and meet people in your local community who share your interests.',
    'favicon' => 'https://secure.meetupstatic.com/next/images/general/favicon.ico',
    'feeds' => [],
    'icon' => 'https://secure.meetupstatic.com/next/images/general/m_swarm_120x120.png',
    'image' => 'https://secure.meetupstatic.com/next/images/shared/meetup-logo.jpg',
    'keywords' => [],
    'language' => 'en-US',
    'languages' => [],
    'license' => null,
    'providerName' => 'Meetup',
    'providerUrl' => 'https://www.meetup.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Login to Meetup | Meetup',
    'url' => 'https://www.meetup.com/login/?returnUri=https%3A%2F%2Fwww.meetup.com%2Fgpul-labs%2Fevents%2F248885422%2F',
    'linkedData' => [
        '@type' => 'Organization',
        '@context' => 'https://schema.org',
        'url' => 'https://www.meetup.com/login/',
        'name' => 'Meetup',
        'logo' => 'https://secure.meetupstatic.com/next/images/general/m_swarm_630x630.png',
        'sameAs' => [
            'https://www.facebook.com/meetup/',
            'https://twitter.com/Meetup/',
            'https://www.youtube.com/meetup',
            'https://www.instagram.com/meetup/'
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@type' => 'Organization',
            '@context' => 'https://schema.org',
            'url' => 'https://www.meetup.com/login/',
            'name' => 'Meetup',
            'logo' => 'https://secure.meetupstatic.com/next/images/general/m_swarm_630x630.png',
            'sameAs' => [
                'https://www.facebook.com/meetup/',
                'https://twitter.com/Meetup/',
                'https://www.youtube.com/meetup',
                'https://www.instagram.com/meetup/'
            ]
        ]
    ]
];
