<?php
declare(strict_types = 1);

return [
    'authorName' => 'smshdchrb',
    'authorUrl' => 'https://www.youtube.com/@smshdchrb',
    'cms' => null,
    'code' => [
        'html' => '<iframe width="200" height="150" src="https://www.youtube.com/embed/eiHXASgRTcA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen title="Noisy kittens waiting for dinner!"></iframe>',
        'width' => 200,
        'height' => 150,
        'ratio' => 75.0
    ],
    'description' => '7 week old fostered kittens waiting on their dinner being prepared. They had been ill with cat flu and were just starting to get their appetite back. Because...',
    'favicon' => 'https://www.youtube.com/s/desktop/ae4ecf92/img/favicon.ico',
    'feeds' => [],
    'icon' => 'https://www.youtube.com/s/desktop/ae4ecf92/img/favicon_144x144.png',
    'image' => 'https://i.ytimg.com/vi/eiHXASgRTcA/hqdefault.jpg',
    'keywords' => [
        'kittens',
        'cats',
        'hungry',
        'cat',
        'baby',
        'eight',
        'weeks',
        'old',
        'noisy',
        'meow',
        'funny',
        'kitties',
        'feline',
        'dinner',
        'excited',
        'loud',
        'cute',
        'pet',
        'food',
        'time',
        'felix',
        'kitty',
        'catz',
        'lolcat',
        'kitten',
        'talking',
        'adorable',
        'climbing'
    ],
    'language' => 'es-ES',
    'languages' => [],
    'license' => null,
    'providerName' => 'YouTube',
    'providerUrl' => 'https://www.youtube.com/',
    'publishedTime' => '2008-10-04 13:06:22',
    'redirect' => null,
    'title' => 'Noisy kittens waiting for dinner!',
    'url' => 'https://www.youtube.com/watch?v=eiHXASgRTcA',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'BreadcrumbList',
        'itemListElement' => [
            [
                '@type' => 'ListItem',
                'position' => 1,
                'item' => [
                    '@id' => 'http://www.youtube.com/@smshdchrb',
                    'name' => 'smshdchrb'
                ]
            ]
        ]
    ],
    'oEmbed' => [
        'title' => 'Noisy kittens waiting for dinner!',
        'author_name' => 'smshdchrb',
        'author_url' => 'https://www.youtube.com/@smshdchrb',
        'type' => 'video',
        'height' => 150,
        'width' => 200,
        'version' => '1.0',
        'provider_name' => 'YouTube',
        'provider_url' => 'https://www.youtube.com/',
        'thumbnail_height' => 360,
        'thumbnail_width' => 480,
        'thumbnail_url' => 'https://i.ytimg.com/vi/eiHXASgRTcA/hqdefault.jpg',
        'html' => '<iframe width="200" height="150" src="https://www.youtube.com/embed/eiHXASgRTcA?feature=oembed" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen title="Noisy kittens waiting for dinner!"></iframe>'
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'BreadcrumbList',
            'itemListElement' => [
                [
                    '@type' => 'ListItem',
                    'position' => 1,
                    'item' => [
                        '@id' => 'http://www.youtube.com/@smshdchrb',
                        'name' => 'smshdchrb'
                    ]
                ]
            ]
        ]
    ]
];
