<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://player.twitch.tv/?video=72749628&amp;player=facebook&amp;autoplay=true&amp;parent=meta.tag" frameborder="0" width="640" height="360" allowTransparency="true"></iframe>',
        'width' => 640,
        'height' => 360,
        'ratio' => 56.25
    ],
    'description' => 'riotgames went live on Twitch. Catch up on their League of Legends VOD now.',
    'favicon' => 'https://assets.twitch.tv/assets/favicon-32-e29e246c157142c94346.png',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://static-cdn.jtvnw.net/cf_vods/d2nvs31859zcd8/d44201bac3_riotgames_21876932832_470478938/thumb/thumb0-640x360.jpg',
    'keywords' => [],
    'language' => null,
    'languages' => [
        'bg' => 'https://www.twitch.tv/videos/72749628?lang=bg',
        'cs' => 'https://www.twitch.tv/videos/72749628?lang=cs',
        'da' => 'https://www.twitch.tv/videos/72749628?lang=da',
        'de' => 'https://www.twitch.tv/videos/72749628?lang=de',
        'el' => 'https://www.twitch.tv/videos/72749628?lang=el',
        'es' => 'https://www.twitch.tv/videos/72749628?lang=es',
        'es-mx' => 'https://www.twitch.tv/videos/72749628?lang=es-mx',
        'fi' => 'https://www.twitch.tv/videos/72749628?lang=fi',
        'fr' => 'https://www.twitch.tv/videos/72749628?lang=fr',
        'hu' => 'https://www.twitch.tv/videos/72749628?lang=hu',
        'it' => 'https://www.twitch.tv/videos/72749628?lang=it',
        'ja' => 'https://www.twitch.tv/videos/72749628?lang=ja',
        'ko' => 'https://www.twitch.tv/videos/72749628?lang=ko',
        'nl' => 'https://www.twitch.tv/videos/72749628?lang=nl',
        'no' => 'https://www.twitch.tv/videos/72749628?lang=no',
        'pl' => 'https://www.twitch.tv/videos/72749628?lang=pl',
        'pt' => 'https://www.twitch.tv/videos/72749628?lang=pt',
        'pt-br' => 'https://www.twitch.tv/videos/72749628?lang=pt-br',
        'ro' => 'https://www.twitch.tv/videos/72749628?lang=ro',
        'ru' => 'https://www.twitch.tv/videos/72749628?lang=ru',
        'sk' => 'https://www.twitch.tv/videos/72749628?lang=sk',
        'sv' => 'https://www.twitch.tv/videos/72749628?lang=sv',
        'th' => 'https://www.twitch.tv/videos/72749628?lang=th',
        'tr' => 'https://www.twitch.tv/videos/72749628?lang=tr',
        'vi' => 'https://www.twitch.tv/videos/72749628?lang=vi',
        'zh-cn' => 'https://www.twitch.tv/videos/72749628?lang=zh-cn',
        'zh-tw' => 'https://www.twitch.tv/videos/72749628?lang=zh-tw',
        'x-default' => 'https://www.twitch.tv/videos/72749628'
    ],
    'license' => null,
    'providerName' => 'Twitch',
    'providerUrl' => 'https://www.twitch.tv',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'EU LCS Summer - Week 3 Day 1: FNC vs. S04 | H2K vs. G2 (EULCS2) - riotgames on Twitch',
    'url' => 'https://www.twitch.tv/videos/72749628',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@graph' => [
            [
                '@type' => 'VideoObject',
                'description' => 'riotgames went live on Twitch. Catch up on their League of Legends VOD now.',
                'embedUrl' => 'https://www.twitch.tv/videos/72749628',
                'name' => 'EU LCS Summer - Week 3 Day 1: FNC vs. S04 | H2K vs. G2 (EULCS2)',
                'thumbnailUrl' => [
                    'https://static-cdn.jtvnw.net/cf_vods/d2nvs31859zcd8/d44201bac3_riotgames_21876932832_470478938/thumb/thumb0-640x360.jpg'
                ],
                'uploadDate' => '2016-06-16T13:30:57Z',
                'duration' => 'PT2180S',
                'interactionStatistic' => [
                    '@type' => 'InteractionCounter',
                    'interactionType' => [
                        '@type' => 'http://schema.org/WatchAction'
                    ],
                    'userInteractionCount' => 1589
                ]
            ]
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@graph' => [
                [
                    '@type' => 'VideoObject',
                    'description' => 'riotgames went live on Twitch. Catch up on their League of Legends VOD now.',
                    'embedUrl' => 'https://www.twitch.tv/videos/72749628',
                    'name' => 'EU LCS Summer - Week 3 Day 1: FNC vs. S04 | H2K vs. G2 (EULCS2)',
                    'thumbnailUrl' => [
                        'https://static-cdn.jtvnw.net/cf_vods/d2nvs31859zcd8/d44201bac3_riotgames_21876932832_470478938/thumb/thumb0-640x360.jpg'
                    ],
                    'uploadDate' => '2016-06-16T13:30:57Z',
                    'duration' => 'PT2180S',
                    'interactionStatistic' => [
                        '@type' => 'InteractionCounter',
                        'interactionType' => [
                            '@type' => 'http://schema.org/WatchAction'
                        ],
                        'userInteractionCount' => 1589
                    ]
                ]
            ]
        ]
    ]
];
