<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Poll Answers: Option #1, Option #2,',
    'favicon' => 'https://app.crowdsignal.com/images/favicon.png',
    'feeds' => [
        'https://poll.fm/7012505/feed'
    ],
    'icon' => null,
    'image' => 'https://app.crowdsignal.com/images/twitter-card.png',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Poll',
    'providerUrl' => 'https://poll.fm',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Which design do you prefer?',
    'url' => 'https://poll.fm/7012505',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
