<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Store your photos and videos online with secure storage from Photobucket. Available on iOS, Android and desktop. Securely backup your memories and sign up today!',
    'favicon' => 'https://media.photobucket.com/favicon.ico',
    'feeds' => [],
    'icon' => 'https://media.photobucket.com/logo192.png',
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Photobucket',
    'providerUrl' => 'https://media.photobucket.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Photo Storage',
    'url' => 'https://media.photobucket.com/user/Ignwar/media/Album%20Deserts/MoonriseMonumentValleyUtah.jpg.html?filters%5Bterm%5D=sunsets&filters%5Bprimary%5D=images',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
