<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe style="border-radius: 12px" width="100%" height="352" title="Spotify Embed: A Cantar con Xabarin (Vol. I e II)" frameborder="0" allowfullscreen allow="autoplay; clipboard-write; encrypted-media; fullscreen; picture-in-picture" loading="lazy" src="https://open.spotify.com/embed/album/7s66wU1XJ2NsUuWM2NKiUV?utm_source=oembed"></iframe>',
        'width' => 456,
        'height' => 352,
        'ratio' => 77.193
    ],
    'description' => 'Xabarin · Album · 1994 · 44 songs.',
    'favicon' => 'https://open.spotifycdn.com/cdn/images/favicon32.b64ecc03.png',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://i.scdn.co/image/ab67616d00001e022dd9ff41aad54c1d93d50aa6',
    'keywords' => [],
    'language' => 'en',
    'languages' => [
        'x-default' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
        'en' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
        'id' => 'https://open.spotify.com/intl-id/album/7s66wU1XJ2NsUuWM2NKiUV',
        'de' => 'https://open.spotify.com/intl-de/album/7s66wU1XJ2NsUuWM2NKiUV',
        'pt' => 'https://open.spotify.com/intl-pt/album/7s66wU1XJ2NsUuWM2NKiUV',
        'ja' => 'https://open.spotify.com/intl-ja/album/7s66wU1XJ2NsUuWM2NKiUV',
        'fr' => 'https://open.spotify.com/intl-fr/album/7s66wU1XJ2NsUuWM2NKiUV',
        'ar' => 'https://open.spotify.com/intl-ar/album/7s66wU1XJ2NsUuWM2NKiUV',
        'es' => 'https://open.spotify.com/intl-es/album/7s66wU1XJ2NsUuWM2NKiUV',
        'tr' => 'https://open.spotify.com/intl-tr/album/7s66wU1XJ2NsUuWM2NKiUV',
        'it' => 'https://open.spotify.com/intl-it/album/7s66wU1XJ2NsUuWM2NKiUV'
    ],
    'license' => null,
    'providerName' => 'Spotify',
    'providerUrl' => 'https://spotify.com/',
    'publishedTime' => '1994-03-01 00:00:00',
    'redirect' => null,
    'title' => 'A Cantar con Xabarin (Vol. I e II)',
    'url' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
    'linkedData' => [
        '@context' => 'http://schema.googleapis.com/',
        '@type' => 'MusicAlbum',
        '@id' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
        'url' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
        'name' => 'A Cantar con Xabarin (Vol. I e II)',
        'description' => 'Listen to A Cantar con Xabarin (Vol. I e II) on Spotify. Xabarin · Album · 1994 · 44 songs.',
        'datePublished' => '1994-03-01',
        'potentialAction' => [
            '@type' => 'ListenAction',
            'target' => [
                [
                    '@type' => 'EntryPoint',
                    'urlTemplate' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV?autoplay=true',
                    'actionPlatform' => [
                        'http://schema.org/DesktopWebPlatform',
                        'http://schema.org/IOSPlatform',
                        'http://schema.googleapis.com/GoogleAudioCast',
                        'http://schema.googleapis.com/GoogleVideoCast'
                    ]
                ],
                'android-app://com.spotify.music/spotify/album/7s66wU1XJ2NsUuWM2NKiUV/play'
            ],
            'expectsAcceptanceOf' => [
                '@type' => 'Offer',
                'category' => 'free',
                'eligibleRegion' => []
            ]
        ]
    ],
    'oEmbed' => [
        'html' => '<iframe style="border-radius: 12px" width="100%" height="352" title="Spotify Embed: A Cantar con Xabarin (Vol. I e II)" frameborder="0" allowfullscreen allow="autoplay; clipboard-write; encrypted-media; fullscreen; picture-in-picture" loading="lazy" src="https://open.spotify.com/embed/album/7s66wU1XJ2NsUuWM2NKiUV?utm_source=oembed"></iframe>',
        'iframe_url' => 'https://open.spotify.com/embed/album/7s66wU1XJ2NsUuWM2NKiUV?utm_source=oembed',
        'width' => 456,
        'height' => 352,
        'version' => '1.0',
        'provider_name' => 'Spotify',
        'provider_url' => 'https://spotify.com',
        'type' => 'rich',
        'title' => 'A Cantar con Xabarin (Vol. I e II)',
        'thumbnail_url' => 'https://i.scdn.co/image/ab67616d00001e022dd9ff41aad54c1d93d50aa6',
        'thumbnail_width' => 300,
        'thumbnail_height' => 300
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.googleapis.com/',
            '@type' => 'MusicAlbum',
            '@id' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
            'url' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV',
            'name' => 'A Cantar con Xabarin (Vol. I e II)',
            'description' => 'Listen to A Cantar con Xabarin (Vol. I e II) on Spotify. Xabarin · Album · 1994 · 44 songs.',
            'datePublished' => '1994-03-01',
            'potentialAction' => [
                '@type' => 'ListenAction',
                'target' => [
                    [
                        '@type' => 'EntryPoint',
                        'urlTemplate' => 'https://open.spotify.com/album/7s66wU1XJ2NsUuWM2NKiUV?autoplay=true',
                        'actionPlatform' => [
                            'http://schema.org/DesktopWebPlatform',
                            'http://schema.org/IOSPlatform',
                            'http://schema.googleapis.com/GoogleAudioCast',
                            'http://schema.googleapis.com/GoogleVideoCast'
                        ]
                    ],
                    'android-app://com.spotify.music/spotify/album/7s66wU1XJ2NsUuWM2NKiUV/play'
                ],
                'expectsAcceptanceOf' => [
                    '@type' => 'Offer',
                    'category' => 'free',
                    'eligibleRegion' => []
                ]
            ]
        ]
    ]
];
