<?php
declare(strict_types = 1);

return [
    'authorName' => '@animoto',
    'authorUrl' => 'https://twitter.com/animoto',
    'cms' => null,
    'code' => null,
    'description' => 'Create, edit, and share videos with our free video maker. Combine your photos, video clips, and music to make quality videos in minutes. Get started free!',
    'favicon' => 'https://animoto.com/favicon-32x32.png?v=f7bad0df2a4af8688773dca5ee0b1ed6',
    'feeds' => [
        'https://animoto.com/rss.xml'
    ],
    'icon' => 'https://animoto.com/icons/icon-48x48.png?v=f7bad0df2a4af8688773dca5ee0b1ed6',
    'image' => null,
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Animoto',
    'providerUrl' => 'https://animoto.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Free Video Maker | Create & Edit Your Videos Easily',
    'url' => 'https://animoto.com/play/GjsJ1gu0WDRfr4pGw12xZQ',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'WebSite',
        'url' => 'https://animoto.com',
        'name' => 'Animoto video maker - Stand out on social media. Easily.',
        'alternateName' => ''
    ],
    'oEmbed' => [
        'error' => 'URL not supported or not found',
        'url' => 'https://animoto.com/play/GjsJ1gu0WDRfr4pGw12xZQ'
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'WebSite',
            'url' => 'https://animoto.com',
            'name' => 'Animoto video maker - Stand out on social media. Easily.',
            'alternateName' => ''
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'VideoObject',
            'name' => 'Animoto: Free Online Video Maker',
            'contentUrl' => 'https://d2of6bhnpl91ni.cloudfront.net/cms/animoto-free-online-video-maker-e8d6870030.mp4',
            'description' => 'With Animoto, you\'ll have everything you need to create your own professional videos in minutes. No experience required. All it takes is an idea. ',
            'thumbnailUrl' => '//images.ctfassets.net/00i767ygo3tc/010bacg5wwIhMMx6xYS3qj/18e39c5d16f5614a3b477a284faea1a2/free-online-video-maker.webp',
            'transcript' => 'We all have a story to tell, and video is the best way to make yours stand out. With Animoto, you\'ll have everything you need to create your own professional videos in minutes. No experience required. All it takes is an idea. We\'ve made it easy to get started with customizable templates for everything from saying Happy Birthday to selling your product. From there, it\'s as simple as dragging and dropping your photos and video clips, choosing from our millions of Getty stock images or recording with our built-in screen and webcam recorder. Customize your videos with transitions, music, voiceovers, and more. Then bring your videos on brand with a single click. Make sure your story is heard with Animoto. Everything you need to create your own videos is right at your fingertips. Start creating for free.',
            'uploadDate' => '2020-09-15T21:58:55.636Z'
        ]
    ]
];
