<?php
declare(strict_types = 1);

return [
    'authorName' => 'Antena 3 Noticias',
    'authorUrl' => 'https://www.tiktok.com/@a3noticias',
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="tiktok-embed" cite="https://www.tiktok.com/@a3noticias/video/6806030056956251397" data-video-id="6806030056956251397" data-embed-from="oembed" style="max-width:605px; min-width:325px;"> <section> <a target="_blank" title="@a3noticias" href="https://www.tiktok.com/@a3noticias?refer=embed">@a3noticias</a> <p>Nuestro <a title="aplausosanitario" target="_blank" href="https://www.tiktok.com/tag/aplausosanitario?refer=embed">#AplausoSanitario</a> más sincero. Para todos. Y recuerda, <a title="quédateencasa" target="_blank" href="https://www.tiktok.com/tag/qu%C3%A9dateencasa?refer=embed">#QuédateEnCasa</a></p> <a target="_blank" title="♬ Resistiré - Duo Dinamico" href="https://www.tiktok.com/music/Resistiré-250824169968246784?refer=embed">♬ Resistiré - Duo Dinamico</a> </section> </blockquote> <script async src="https://www.tiktok.com/embed.js"></script>',
        'width' => null,
        'height' => null,
        'ratio' => null
    ],
    'description' => null,
    'favicon' => 'https://www.tiktok.com/favicon.ico',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://p77-sign-va.tiktokcdn.com/obj/tos-maliva-p-0068/165175e006354d838501378cfb325b79_1584652367?x-expires=1718204400&x-signature=weANzY8AXzX93c5j7jm34neMhWY%3D',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'TikTok',
    'providerUrl' => 'https://www.tiktok.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Nuestro #AplausoSanitario más sincero. Para todos. Y recuerda, #QuédateEnCasa',
    'url' => 'https://www.tiktok.com/@a3noticias/video/6806030056956251397',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'video',
        'title' => 'Nuestro #AplausoSanitario más sincero. Para todos. Y recuerda, #QuédateEnCasa',
        'author_url' => 'https://www.tiktok.com/@a3noticias',
        'author_name' => 'Antena 3 Noticias',
        'width' => '100%',
        'height' => '100%',
        'html' => '<blockquote class="tiktok-embed" cite="https://www.tiktok.com/@a3noticias/video/6806030056956251397" data-video-id="6806030056956251397" data-embed-from="oembed" style="max-width:605px; min-width:325px;"> <section> <a target="_blank" title="@a3noticias" href="https://www.tiktok.com/@a3noticias?refer=embed">@a3noticias</a> <p>Nuestro <a title="aplausosanitario" target="_blank" href="https://www.tiktok.com/tag/aplausosanitario?refer=embed">#AplausoSanitario</a> más sincero. Para todos. Y recuerda, <a title="quédateencasa" target="_blank" href="https://www.tiktok.com/tag/qu%C3%A9dateencasa?refer=embed">#QuédateEnCasa</a></p> <a target="_blank" title="♬ Resistiré - Duo Dinamico" href="https://www.tiktok.com/music/Resistiré-250824169968246784?refer=embed">♬ Resistiré - Duo Dinamico</a> </section> </blockquote> <script async src="https://www.tiktok.com/embed.js"></script>',
        'thumbnail_width' => 480,
        'thumbnail_height' => 848,
        'thumbnail_url' => 'https://p77-sign-va.tiktokcdn.com/obj/tos-maliva-p-0068/165175e006354d838501378cfb325b79_1584652367?x-expires=1718204400&x-signature=weANzY8AXzX93c5j7jm34neMhWY%3D',
        'provider_url' => 'https://www.tiktok.com',
        'provider_name' => 'TikTok',
        'author_unique_id' => 'a3noticias',
        'embed_product_id' => '6806030056956251397',
        'embed_type' => 'video'
    ],
    'allLinkedData' => []
];
