<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Listen in to popular podcasts and radio shows from around the world or start your own with Spreaker!',
    'favicon' => 'https://d1sojsgu0jwtb7.cloudfront.net/images/favicons/spreaker/favicon.ico',
    'feeds' => [],
    'icon' => 'https://d1sojsgu0jwtb7.cloudfront.net/images/favicons/spreaker/apple-touch-icon.png',
    'image' => 'https://d1sojsgu0jwtb7.cloudfront.net/images/og_image.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Spreaker',
    'providerUrl' => 'https://www.spreaker.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Spreaker',
    'url' => 'https://www.spreaker.com/user/angelclark/angel-clark-ice-cream-tocos',
    'linkedData' => [],
    'oEmbed' => [
        'response' => [
            'error' => [
                'messages' => [
                    'The input URL does not match any supported resource on Spreaker.'
                ],
                'code' => 404
            ]
        ]
    ],
    'allLinkedData' => []
];
