<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'amCharts live editor: create, configure, tweak, edit data, export, import, save, share in a single interface, the user-friendly way.',
    'favicon' => 'https://live.amcharts.com/static/img/page/favicon.png',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://live.amcharts.com/static/img/page/editor-shot.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'amCharts',
    'providerUrl' => 'https://live.amcharts.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Live Chart Editor',
    'url' => 'https://live.amcharts.com/czNjJ/',
    'linkedData' => [],
    'oEmbed' => [],
    'allLinkedData' => []
];
