<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://player.vimeo.com/video/235352744?app_id=122963" width="640" height="360" frameborder="0" allow="autoplay; fullscreen; picture-in-picture; clipboard-write"></iframe>',
        'width' => 640,
        'height' => 360,
        'ratio' => 56.25
    ],
    'description' => 'Sorry, we couldn’t find that page',
    'favicon' => 'https://f.vimeocdn.com/images_v6/favicon.ico?75abfbb122dbdc379bb1a024f2874f879d5a01a1',
    'feeds' => [],
    'icon' => 'https://i.vimeocdn.com/favicon/main-touch_180',
    'image' => null,
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Vimeo',
    'providerUrl' => 'https://vimeo.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'VimeUhOh',
    'url' => 'https://vimeo.com/235352744',
    'linkedData' => [],
    'oEmbed' => [
        'type' => 'video',
        'version' => '1.0',
        'provider_name' => 'Vimeo',
        'provider_url' => 'https://vimeo.com/',
        'html' => '<iframe src="https://player.vimeo.com/video/235352744?app_id=122963" width="640" height="360" frameborder="0" allow="autoplay; fullscreen; picture-in-picture; clipboard-write"></iframe>',
        'width' => 640,
        'height' => 360,
        'video_id' => 235352744,
        'uri' => '/videos/235352744:ebd66989cc'
    ],
    'allLinkedData' => []
];
