<?php
declare(strict_types = 1);

return [
    'authorName' => 'sakimichan',
    'authorUrl' => 'https://www.deviantart.com/sakimichan',
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://st.deviantart.net/eclipse/icons/da_favicon_v2.ico',
    'feeds' => [],
    'icon' => 'https://st.deviantart.net/eclipse/icons/ios-180.png',
    'image' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/9ad8fbc8-aee8-4e92-a04b-6abf7a036a51/d8foa93-8e1fade9-1853-4644-af82-2ec21590bf94.jpg/v1/fit/w_300,h_900,q_70,strp/misty_by_sakimichan_d8foa93-300w.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9OTAwIiwicGF0aCI6IlwvZlwvOWFkOGZiYzgtYWVlOC00ZTkyLWEwNGItNmFiZjdhMDM2YTUxXC9kOGZvYTkzLThlMWZhZGU5LTE4NTMtNDY0NC1hZjgyLTJlYzIxNTkwYmY5NC5qcGciLCJ3aWR0aCI6Ijw9Njk1In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.ms0Mi2WrZ6RA_clNOJNYh5k9Ow2CkK06A_NmVeMS4hM',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'DeviantArt',
    'providerUrl' => 'https://www.deviantart.com/',
    'publishedTime' => '2015-01-27 16:55:07',
    'redirect' => null,
    'title' => 'Misty',
    'url' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/9ad8fbc8-aee8-4e92-a04b-6abf7a036a51/d8foa93-8e1fade9-1853-4644-af82-2ec21590bf94.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7InBhdGgiOiJcL2ZcLzlhZDhmYmM4LWFlZTgtNGU5Mi1hMDRiLTZhYmY3YTAzNmE1MVwvZDhmb2E5My04ZTFmYWRlOS0xODUzLTQ2NDQtYWY4Mi0yZWMyMTU5MGJmOTQuanBnIn1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmZpbGUuZG93bmxvYWQiXX0._JiXuDZWqsoAgateXxPBaC3_EPfHdri7pJCeKFhXnjA',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'photo',
        'title' => 'Misty',
        'category' => 'Fan Art > Digital Art > Drawings > Games',
        'url' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/9ad8fbc8-aee8-4e92-a04b-6abf7a036a51/d8foa93-8e1fade9-1853-4644-af82-2ec21590bf94.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7InBhdGgiOiJcL2ZcLzlhZDhmYmM4LWFlZTgtNGU5Mi1hMDRiLTZhYmY3YTAzNmE1MVwvZDhmb2E5My04ZTFmYWRlOS0xODUzLTQ2NDQtYWY4Mi0yZWMyMTU5MGJmOTQuanBnIn1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmZpbGUuZG93bmxvYWQiXX0._JiXuDZWqsoAgateXxPBaC3_EPfHdri7pJCeKFhXnjA',
        'author_name' => 'sakimichan',
        'author_url' => 'https://www.deviantart.com/sakimichan',
        'provider_name' => 'DeviantArt',
        'provider_url' => 'https://www.deviantart.com',
        'safety' => 'nonadult',
        'pubdate' => '2015-01-27T16:55:07-08:00',
        'community' => [
            'statistics' => [
                '_attributes' => [
                    'views' => 386632,
                    'favorites' => 22702,
                    'comments' => 675,
                    'downloads' => 0
                ]
            ]
        ],
        'copyright' => [
            '_attributes' => [
                'url' => 'https://www.deviantart.com/sakimichan',
                'year' => '2015',
                'entity' => 'sakimichan'
            ]
        ],
        'width' => '695',
        'height' => '900',
        'imagetype' => 'jpg',
        'thumbnail_url' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/9ad8fbc8-aee8-4e92-a04b-6abf7a036a51/d8foa93-8e1fade9-1853-4644-af82-2ec21590bf94.jpg/v1/fit/w_300,h_900,q_70,strp/misty_by_sakimichan_d8foa93-300w.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9OTAwIiwicGF0aCI6IlwvZlwvOWFkOGZiYzgtYWVlOC00ZTkyLWEwNGItNmFiZjdhMDM2YTUxXC9kOGZvYTkzLThlMWZhZGU5LTE4NTMtNDY0NC1hZjgyLTJlYzIxNTkwYmY5NC5qcGciLCJ3aWR0aCI6Ijw9Njk1In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.ms0Mi2WrZ6RA_clNOJNYh5k9Ow2CkK06A_NmVeMS4hM',
        'thumbnail_width' => 300,
        'thumbnail_height' => 388,
        'thumbnail_url_150' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/9ad8fbc8-aee8-4e92-a04b-6abf7a036a51/d8foa93-8e1fade9-1853-4644-af82-2ec21590bf94.jpg/v1/fit/w_150,h_150,q_70,strp/misty_by_sakimichan_d8foa93-150.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9OTAwIiwicGF0aCI6IlwvZlwvOWFkOGZiYzgtYWVlOC00ZTkyLWEwNGItNmFiZjdhMDM2YTUxXC9kOGZvYTkzLThlMWZhZGU5LTE4NTMtNDY0NC1hZjgyLTJlYzIxNTkwYmY5NC5qcGciLCJ3aWR0aCI6Ijw9Njk1In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.ms0Mi2WrZ6RA_clNOJNYh5k9Ow2CkK06A_NmVeMS4hM',
        'thumbnail_url_200h' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/9ad8fbc8-aee8-4e92-a04b-6abf7a036a51/d8foa93-8e1fade9-1853-4644-af82-2ec21590bf94.jpg/v1/crop/w_154,h_200,x_0,y_0,scl_0.22302158273381,q_70,strp/misty_by_sakimichan_d8foa93-200h.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9OTAwIiwicGF0aCI6IlwvZlwvOWFkOGZiYzgtYWVlOC00ZTkyLWEwNGItNmFiZjdhMDM2YTUxXC9kOGZvYTkzLThlMWZhZGU5LTE4NTMtNDY0NC1hZjgyLTJlYzIxNTkwYmY5NC5qcGciLCJ3aWR0aCI6Ijw9Njk1In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.ms0Mi2WrZ6RA_clNOJNYh5k9Ow2CkK06A_NmVeMS4hM',
        'thumbnail_width_200h' => 154,
        'thumbnail_height_200h' => 200
    ],
    'allLinkedData' => []
];
