<?php
declare(strict_types = 1);

return [
    'authorName' => 'pachunka',
    'authorUrl' => 'https://www.deviantart.com/pachunka',
    'cms' => null,
    'code' => null,
    'description' => null,
    'favicon' => 'https://st.deviantart.net/eclipse/icons/da_favicon_v2.ico',
    'feeds' => [],
    'icon' => 'https://st.deviantart.net/eclipse/icons/ios-180.png',
    'image' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/2b5a457d-dde7-459a-badf-774e8e506025/d2enxz7-431ca9c3-987f-4b2d-ae6a-cbbdd1c0e2bf.jpg/v1/fit/w_300,h_672,q_70,strp/cope_by_pachunka_d2enxz7-300w.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9NjcyIiwicGF0aCI6IlwvZlwvMmI1YTQ1N2QtZGRlNy00NTlhLWJhZGYtNzc0ZThlNTA2MDI1XC9kMmVueHo3LTQzMWNhOWMzLTk4N2YtNGIyZC1hZTZhLWNiYmRkMWMwZTJiZi5qcGciLCJ3aWR0aCI6Ijw9NDQ4In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.IgIuTtYswRRSrLcUD8alCdW0sAgmkVTiQAjV5-OCfv8',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'DeviantArt',
    'providerUrl' => 'https://www.deviantart.com/',
    'publishedTime' => '2009-12-02 23:59:51',
    'redirect' => null,
    'title' => 'Cope',
    'url' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/2b5a457d-dde7-459a-badf-774e8e506025/d2enxz7-431ca9c3-987f-4b2d-ae6a-cbbdd1c0e2bf.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7InBhdGgiOiJcL2ZcLzJiNWE0NTdkLWRkZTctNDU5YS1iYWRmLTc3NGU4ZTUwNjAyNVwvZDJlbnh6Ny00MzFjYTljMy05ODdmLTRiMmQtYWU2YS1jYmJkZDFjMGUyYmYuanBnIn1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmZpbGUuZG93bmxvYWQiXX0.pCEF4M_tMVZI92ZKClZdcMu5UqpQ3131DrHsx1WxefY',
    'linkedData' => [],
    'oEmbed' => [
        'version' => '1.0',
        'type' => 'photo',
        'title' => 'Cope',
        'category' => 'Digital Art > Drawings & Paintings > Illustrations > Conceptual',
        'url' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/2b5a457d-dde7-459a-badf-774e8e506025/d2enxz7-431ca9c3-987f-4b2d-ae6a-cbbdd1c0e2bf.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7InBhdGgiOiJcL2ZcLzJiNWE0NTdkLWRkZTctNDU5YS1iYWRmLTc3NGU4ZTUwNjAyNVwvZDJlbnh6Ny00MzFjYTljMy05ODdmLTRiMmQtYWU2YS1jYmJkZDFjMGUyYmYuanBnIn1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmZpbGUuZG93bmxvYWQiXX0.pCEF4M_tMVZI92ZKClZdcMu5UqpQ3131DrHsx1WxefY',
        'author_name' => 'pachunka',
        'author_url' => 'https://www.deviantart.com/pachunka',
        'provider_name' => 'DeviantArt',
        'provider_url' => 'https://www.deviantart.com',
        'safety' => 'nonadult',
        'pubdate' => '2009-12-02T23:59:51-08:00',
        'community' => [
            'statistics' => [
                '_attributes' => [
                    'views' => 3279,
                    'favorites' => 10,
                    'comments' => 5,
                    'downloads' => 63
                ]
            ]
        ],
        'copyright' => [
            '_attributes' => [
                'url' => 'https://www.deviantart.com/pachunka',
                'year' => '2009',
                'entity' => 'pachunka'
            ]
        ],
        'width' => '448',
        'height' => '672',
        'imagetype' => 'jpg',
        'thumbnail_url' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/2b5a457d-dde7-459a-badf-774e8e506025/d2enxz7-431ca9c3-987f-4b2d-ae6a-cbbdd1c0e2bf.jpg/v1/fit/w_300,h_672,q_70,strp/cope_by_pachunka_d2enxz7-300w.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9NjcyIiwicGF0aCI6IlwvZlwvMmI1YTQ1N2QtZGRlNy00NTlhLWJhZGYtNzc0ZThlNTA2MDI1XC9kMmVueHo3LTQzMWNhOWMzLTk4N2YtNGIyZC1hZTZhLWNiYmRkMWMwZTJiZi5qcGciLCJ3aWR0aCI6Ijw9NDQ4In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.IgIuTtYswRRSrLcUD8alCdW0sAgmkVTiQAjV5-OCfv8',
        'thumbnail_width' => 300,
        'thumbnail_height' => 450,
        'thumbnail_url_150' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/2b5a457d-dde7-459a-badf-774e8e506025/d2enxz7-431ca9c3-987f-4b2d-ae6a-cbbdd1c0e2bf.jpg/v1/fit/w_150,h_150,q_70,strp/cope_by_pachunka_d2enxz7-150.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9NjcyIiwicGF0aCI6IlwvZlwvMmI1YTQ1N2QtZGRlNy00NTlhLWJhZGYtNzc0ZThlNTA2MDI1XC9kMmVueHo3LTQzMWNhOWMzLTk4N2YtNGIyZC1hZTZhLWNiYmRkMWMwZTJiZi5qcGciLCJ3aWR0aCI6Ijw9NDQ4In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.IgIuTtYswRRSrLcUD8alCdW0sAgmkVTiQAjV5-OCfv8',
        'thumbnail_url_200h' => 'https://images-wixmp-ed30a86b8c4ca887773594c2.wixmp.com/f/2b5a457d-dde7-459a-badf-774e8e506025/d2enxz7-431ca9c3-987f-4b2d-ae6a-cbbdd1c0e2bf.jpg/v1/fill/w_133,h_200,q_70,strp/cope_by_pachunka_d2enxz7-200h.jpg?token=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJzdWIiOiJ1cm46YXBwOjdlMGQxODg5ODIyNjQzNzNhNWYwZDQxNWVhMGQyNmUwIiwiaXNzIjoidXJuOmFwcDo3ZTBkMTg4OTgyMjY0MzczYTVmMGQ0MTVlYTBkMjZlMCIsIm9iaiI6W1t7ImhlaWdodCI6Ijw9NjcyIiwicGF0aCI6IlwvZlwvMmI1YTQ1N2QtZGRlNy00NTlhLWJhZGYtNzc0ZThlNTA2MDI1XC9kMmVueHo3LTQzMWNhOWMzLTk4N2YtNGIyZC1hZTZhLWNiYmRkMWMwZTJiZi5qcGciLCJ3aWR0aCI6Ijw9NDQ4In1dXSwiYXVkIjpbInVybjpzZXJ2aWNlOmltYWdlLm9wZXJhdGlvbnMiXX0.IgIuTtYswRRSrLcUD8alCdW0sAgmkVTiQAjV5-OCfv8',
        'thumbnail_width_200h' => 133,
        'thumbnail_height_200h' => 200
    ],
    'allLinkedData' => []
];
