<?php
declare(strict_types = 1);

return [
    'authorName' => 'dennisrieves',
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="reddit-embed-bq" style="height:316px" > <a href="https://www.reddit.com/r/investing/comments/7pfpeq/buffett_on_cyrptocurrencies_i_can_say_almost_with/">Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'</a><br> by <a href="https://www.reddit.com/user/dennisrieves/">u/dennisrieves</a> in <a href="https://www.reddit.com/r/investing/">investing</a> </blockquote> <script async src="https://embed.reddit.com/widgets.js" charset="UTF-8"></script>',
        'width' => null,
        'height' => 316,
        'ratio' => null
    ],
    'description' => null,
    'favicon' => 'https://www.reddit.com/favicon.ico',
    'feeds' => [],
    'icon' => 'https://www.redditstatic.com/shreddit/assets/favicon/76x76.png',
    'image' => null,
    'keywords' => [],
    'language' => 'en-US',
    'languages' => [],
    'license' => null,
    'providerName' => 'reddit',
    'providerUrl' => 'https://www.reddit.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'',
    'url' => 'https://www.reddit.com/r/investing/comments/7pfpeq/buffett_on_cyrptocurrencies_i_can_say_almost_with/?rdt=46144',
    'linkedData' => [],
    'oEmbed' => [
        'author_name' => 'dennisrieves',
        'html' => '<blockquote class="reddit-embed-bq" style="height:316px" >
<a href="https://www.reddit.com/r/investing/comments/7pfpeq/buffett_on_cyrptocurrencies_i_can_say_almost_with/">Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'</a><br> by
<a href="https://www.reddit.com/user/dennisrieves/">u/dennisrieves</a> in
<a href="https://www.reddit.com/r/investing/">investing</a>
</blockquote>
<script async src="https://embed.reddit.com/widgets.js" charset="UTF-8"></script>',
        'provider_name' => 'reddit',
        'provider_url' => 'https://www.reddit.com',
        'title' => 'Buffett on cyrptocurrencies: \'I can say almost with certainty that they will come to a bad ending\'',
        'type' => 'rich',
        'height' => 316
    ],
    'allLinkedData' => []
];
