<?php
declare(strict_types = 1);

return [
    'authorName' => 'Cadena SER',
    'authorUrl' => null,
    'cms' => null,
    'code' => null,
    'description' => 'Ana Pontón, candidata del BNG; Xoaquín Fernández Leiceaga, candidato del PSdG-PSOE; Luis Villares, candidato de En Marea, y Pedro Puy, candidato del PP por A Coruña y coordinador del programa electoral de Alberto Núñez Feijoo debaten en Hoy por Hoy',
    'favicon' => 'https://cadenaser.com/pf/resources/img/favicon.png?d=1014',
    'feeds' => [],
    'icon' => null,
    'image' => 'https://cadenaser.com/resizer/a9WQ8rJ3QL6pdxxPeqscG8rnPHU=/1200x630/smart/filters:quality(70)/urotrosfiles.media.streamtheworld.com/otrosfiles/objetos/logos/cadenaser-logo_01.png',
    'keywords' => [],
    'language' => 'es',
    'languages' => [],
    'license' => null,
    'providerName' => 'cadena SER',
    'providerUrl' => 'https://cadenaser.com',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'Debate electoral gallego, en \'Hoy por Hoy\' | Cadena Ser',
    'url' => 'https://cadenaser.com/audio/001RD010000004275766/',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@type' => 'BreadcrumbList',
        'itemListElement' => [
            [
                '@type' => 'ListItem',
                'position' => 1,
                'item' => [
                    '@id' => 'https://cadenaser.com',
                    'name' => 'Inicio'
                ]
            ],
            [
                '@type' => 'ListItem',
                'position' => 2,
                'item' => [
                    '@id' => 'https://cadenaser.com/audio/001RD010000004275766/',
                    'name' => 'Audio 001RD010000004275766'
                ]
            ]
        ]
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@context' => 'https://schema.org',
            '@type' => 'BreadcrumbList',
            'itemListElement' => [
                [
                    '@type' => 'ListItem',
                    'position' => 1,
                    'item' => [
                        '@id' => 'https://cadenaser.com',
                        'name' => 'Inicio'
                    ]
                ],
                [
                    '@type' => 'ListItem',
                    'position' => 2,
                    'item' => [
                        '@id' => 'https://cadenaser.com/audio/001RD010000004275766/',
                        'name' => 'Audio 001RD010000004275766'
                    ]
                ]
            ]
        ]
    ]
];
