<?php
declare(strict_types = 1);

return [
    'authorName' => 'Pepephone',
    'authorUrl' => 'https://twitter.com/pepephone',
    'cms' => null,
    'code' => [
        'html' => '<blockquote class="twitter-tweet"><p lang="es" dir="ltr">RT <a href="https://twitter.com/PabloHerreros?ref_src=twsrc%5Etfw">@PabloHerreros</a> Pepephone rompe la baraja - <a href="http://t.co/mFn7mcB1vy">http://t.co/mFn7mcB1vy</a></p>&mdash; Pepephone (@pepephone) <a href="https://twitter.com/pepephone/status/436461658601713664?ref_src=twsrc%5Etfw">February 20, 2014</a></blockquote> <script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>',
        'width' => 550,
        'height' => null,
        'ratio' => null
    ],
    'description' => null,
    'favicon' => 'https://abs.twimg.com/favicons/twitter-pip.3.ico',
    'feeds' => [],
    'icon' => 'https://abs.twimg.com/responsive-web/client-web/icon-ios.77d25eba.png',
    'image' => null,
    'keywords' => [],
    'language' => null,
    'languages' => [],
    'license' => null,
    'providerName' => 'Twitter',
    'providerUrl' => 'https://twitter.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'x.com',
    'url' => 'https://twitter.com/pepephone/status/436461658601713664',
    'linkedData' => [],
    'oEmbed' => [
        'url' => 'https://twitter.com/pepephone/status/436461658601713664',
        'author_name' => 'Pepephone',
        'author_url' => 'https://twitter.com/pepephone',
        'html' => '<blockquote class="twitter-tweet"><p lang="es" dir="ltr">RT <a href="https://twitter.com/PabloHerreros?ref_src=twsrc%5Etfw">@PabloHerreros</a> Pepephone rompe la baraja - <a href="http://t.co/mFn7mcB1vy">http://t.co/mFn7mcB1vy</a></p>&mdash; Pepephone (@pepephone) <a href="https://twitter.com/pepephone/status/436461658601713664?ref_src=twsrc%5Etfw">February 20, 2014</a></blockquote>
<script async src="https://platform.twitter.com/widgets.js" charset="utf-8"></script>

',
        'width' => 550,
        'height' => null,
        'type' => 'rich',
        'cache_age' => '3153600000',
        'provider_name' => 'Twitter',
        'provider_url' => 'https://twitter.com',
        'version' => '1.0'
    ],
    'api' => [],
    'allLinkedData' => []
];
