<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => null,
    'code' => [
        'html' => '<iframe src="https://bandcamp.com/EmbeddedPlayer/v=2/track=2592086951/size=large/tracklist=false/artwork=small/" frameborder="0" width="350" height="467" allowTransparency="true"></iframe>',
        'width' => 350,
        'height' => 467,
        'ratio' => 133.429
    ],
    'description' => 'from the album Symmetry',
    'favicon' => 'https://f4.bcbits.com/img/a3289609405_3.jpg',
    'feeds' => [],
    'icon' => 'https://f4.bcbits.com/img/a3289609405_3.jpg',
    'image' => 'https://f4.bcbits.com/img/a3289609405_5.jpg',
    'keywords' => [
        'rock',
        'ambient',
        'electro-rock',
        'instrumental',
        'interstellar',
        'sept sorts'
    ],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Bandcamp',
    'providerUrl' => 'https://jeanjean.bandcamp.com',
    'publishedTime' => '2013-09-14 00:00:00',
    'redirect' => null,
    'title' => 'Coquin L\'éléphant, by Jean Jean',
    'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
    'linkedData' => [
        '@type' => 'MusicRecording',
        '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
        'additionalProperty' => [
            [
                '@type' => 'PropertyValue',
                'name' => 'track_id',
                'value' => 2592086951
            ],
            [
                '@type' => 'PropertyValue',
                'name' => 'art_id',
                'value' => 3289609405
            ],
            [
                '@type' => 'PropertyValue',
                'name' => 'license_name',
                'value' => 'all_rights_reserved'
            ],
            [
                '@type' => 'PropertyValue',
                'name' => 'tracknum',
                'value' => 1
            ]
        ],
        'name' => 'Coquin L\'éléphant',
        'duration' => 'P00H03M46S',
        'dateModified' => '13 Sep 2013 18:03:29 GMT',
        'datePublished' => '14 Sep 2013 00:00:00 GMT',
        'inAlbum' => [
            '@type' => 'MusicAlbum',
            'name' => 'Symmetry',
            'albumRelease' => [
                [
                    '@type' => 'MusicRelease',
                    '@id' => 'https://jeanjean.bandcamp.com/album/symmetry',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'item_type',
                            'value' => 'a'
                        ]
                    ]
                ],
                [
                    '@type' => [
                        'MusicRelease',
                        'Product'
                    ],
                    '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
                    'name' => 'Coquin L\'éléphant',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'item_id',
                            'value' => 2592086951
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'item_type',
                            'value' => 't'
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'selling_band_id',
                            'value' => 1235691216
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'type_name',
                            'value' => 'Digital'
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'art_id',
                            'value' => 3289609405
                        ]
                    ],
                    'description' => 'Includes high-quality download in MP3, FLAC and more. Paying supporters also get unlimited streaming via the free Bandcamp app.',
                    'offers' => [
                        '@type' => 'Offer',
                        'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#t2592086951-buy',
                        'priceCurrency' => 'EUR',
                        'price' => 1.0,
                        'priceSpecification' => [
                            'minPrice' => 1.0
                        ],
                        'availability' => 'OnlineOnly'
                    ],
                    'musicReleaseFormat' => 'DigitalFormat',
                    'image' => [
                        'https://f4.bcbits.com/img/a3289609405_10.jpg'
                    ]
                ],
                [
                    '@type' => [
                        'MusicRelease',
                        'Product'
                    ],
                    '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#p1271421079',
                    'name' => '12" Vinyl',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'item_id',
                            'value' => 1271421079
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'item_type',
                            'value' => 'p'
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'selling_band_id',
                            'value' => 1235691216
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'type_name',
                            'value' => 'Vinyl LP'
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'image_ids',
                            'value' => [
                                1822625
                            ]
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'is_music_merch',
                            'value' => true
                        ],
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'type_id',
                            'value' => 2
                        ]
                    ],
                    'offers' => [
                        '@type' => 'Offer',
                        'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#p1271421079-buy',
                        'priceCurrency' => 'EUR',
                        'price' => 12.0,
                        'priceSpecification' => [
                            'minPrice' => 12.0
                        ],
                        'availability' => 'SoldOut',
                        'additionalProperty' => [
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'includes_digital_download',
                                'value' => true
                            ]
                        ]
                    ],
                    'musicReleaseFormat' => 'VinylFormat',
                    'image' => [
                        'https://f4.bcbits.com/img/0001822625_10.jpg'
                    ]
                ]
            ],
            'albumReleaseType' => 'SingleRelease',
            '@id' => 'https://jeanjean.bandcamp.com/album/symmetry',
            'additionalProperty' => [
                [
                    '@type' => 'PropertyValue',
                    'name' => 'download_pref',
                    'value' => 2
                ]
            ]
        ],
        'byArtist' => [
            '@type' => 'MusicGroup',
            'name' => 'Jean Jean',
            '@id' => 'https://jeanjean.bandcamp.com'
        ],
        'publisher' => [
            '@type' => 'MusicGroup',
            '@id' => 'https://jeanjean.bandcamp.com',
            'name' => 'Jean Jean',
            'additionalProperty' => [
                [
                    '@type' => 'PropertyValue',
                    'name' => 'band_id',
                    'value' => 1235691216
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'has_any_downloads',
                    'value' => true
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'has_download_codes',
                    'value' => true
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'image_height',
                    'value' => 1600
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'image_id',
                    'value' => 29836714
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'image_width',
                    'value' => 2279
                ]
            ],
            'image' => 'https://f4.bcbits.com/img/0029836714_10.jpg',
            'genre' => 'https://bandcamp.com/discover/rock',
            'description' => '« On stage, JEAN JEAN is a mirror to their music : deeply intense, smiling and sharing an outra- geous joie-de-vivre. It all seems so simple, but when it builds up, they take you far, very far away » (Christophe Ehrwein)',
            'mainEntityOfPage' => [
                [
                    '@type' => 'WebPage',
                    'url' => 'http://www.facebook.com/jeanjeanmusic',
                    'name' => 'Facebook'
                ],
                [
                    '@type' => 'WebPage',
                    'url' => 'https://www.instagram.com/wearejeanjean/',
                    'name' => 'Instagram'
                ],
                [
                    '@type' => 'WebPage',
                    'url' => 'http://www.youtube.com/channel/UCOsMtEsuiqbqkFQ9oyqJhHg',
                    'name' => 'YouTube'
                ],
                [
                    '@type' => 'WebPage',
                    'url' => 'http://jeanjeanband.com/',
                    'name' => 'jeanjeanband.com'
                ],
                [
                    '@type' => 'WebPage',
                    'url' => 'https://twitter.com/jeanjeanband',
                    'name' => 'Twitter'
                ]
            ],
            'subjectOf' => [
                [
                    '@type' => 'WebPage',
                    'url' => 'https://jeanjean.bandcamp.com/music',
                    'name' => 'music',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'nav_type',
                            'value' => 'm'
                        ]
                    ]
                ],
                [
                    '@type' => 'WebPage',
                    'url' => 'https://jeanjean.bandcamp.com/merch',
                    'name' => 'merch',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'nav_type',
                            'value' => 'p'
                        ]
                    ]
                ],
                [
                    '@type' => 'WebPage',
                    'url' => 'https://jeanjean.bandcamp.com/community',
                    'name' => 'community',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'nav_type',
                            'value' => 'c'
                        ]
                    ]
                ]
            ],
            'foundingLocation' => [
                '@type' => 'Place',
                'name' => 'Sept Sorts, France'
            ]
        ],
        'copyrightNotice' => 'All Rights Reserved',
        'keywords' => [
            'Rock',
            'ambient',
            'electro-rock',
            'instrumental',
            'interstellar',
            'Sept Sorts'
        ],
        'image' => 'https://f4.bcbits.com/img/a3289609405_10.jpg',
        'sponsor' => [
            [
                '@type' => 'Person',
                'url' => 'https://bandcamp.com/jaredremillard',
                'image' => 'https://f4.bcbits.com/img/0001850798_50.jpg',
                'additionalProperty' => [
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'image_id',
                        'value' => 1850798
                    ]
                ],
                'name' => 'Jared ReMillard'
            ],
            [
                '@type' => 'Person',
                'url' => 'https://bandcamp.com/sheebypanda',
                'image' => 'https://f4.bcbits.com/img/0004764347_50.jpg',
                'additionalProperty' => [
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'image_id',
                        'value' => 4764347
                    ]
                ],
                'name' => 'SheebyPanda'
            ],
            [
                '@type' => 'Person',
                'url' => 'https://bandcamp.com/salvajer911',
                'image' => 'https://f4.bcbits.com/img/0017750248_50.jpg',
                'additionalProperty' => [
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'image_id',
                        'value' => 17750248
                    ]
                ],
                'name' => 'Guilhem Sauvage'
            ],
            [
                '@type' => 'Person',
                'url' => 'https://bandcamp.com/tylerthornhill',
                'image' => 'https://f4.bcbits.com/img/0001705921_50.jpg',
                'additionalProperty' => [
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'image_id',
                        'value' => 1705921
                    ]
                ],
                'name' => 'Tyler Thornhill'
            ]
        ],
        'mainEntityOfPage' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
        '@context' => 'https://schema.org'
    ],
    'oEmbed' => [],
    'allLinkedData' => [
        [
            '@type' => 'MusicRecording',
            '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
            'additionalProperty' => [
                [
                    '@type' => 'PropertyValue',
                    'name' => 'track_id',
                    'value' => 2592086951
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'art_id',
                    'value' => 3289609405
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'license_name',
                    'value' => 'all_rights_reserved'
                ],
                [
                    '@type' => 'PropertyValue',
                    'name' => 'tracknum',
                    'value' => 1
                ]
            ],
            'name' => 'Coquin L\'éléphant',
            'duration' => 'P00H03M46S',
            'dateModified' => '13 Sep 2013 18:03:29 GMT',
            'datePublished' => '14 Sep 2013 00:00:00 GMT',
            'inAlbum' => [
                '@type' => 'MusicAlbum',
                'name' => 'Symmetry',
                'albumRelease' => [
                    [
                        '@type' => 'MusicRelease',
                        '@id' => 'https://jeanjean.bandcamp.com/album/symmetry',
                        'additionalProperty' => [
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'item_type',
                                'value' => 'a'
                            ]
                        ]
                    ],
                    [
                        '@type' => [
                            'MusicRelease',
                            'Product'
                        ],
                        '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
                        'name' => 'Coquin L\'éléphant',
                        'additionalProperty' => [
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'item_id',
                                'value' => 2592086951
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'item_type',
                                'value' => 't'
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'selling_band_id',
                                'value' => 1235691216
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'type_name',
                                'value' => 'Digital'
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'art_id',
                                'value' => 3289609405
                            ]
                        ],
                        'description' => 'Includes high-quality download in MP3, FLAC and more. Paying supporters also get unlimited streaming via the free Bandcamp app.',
                        'offers' => [
                            '@type' => 'Offer',
                            'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#t2592086951-buy',
                            'priceCurrency' => 'EUR',
                            'price' => 1.0,
                            'priceSpecification' => [
                                'minPrice' => 1.0
                            ],
                            'availability' => 'OnlineOnly'
                        ],
                        'musicReleaseFormat' => 'DigitalFormat',
                        'image' => [
                            'https://f4.bcbits.com/img/a3289609405_10.jpg'
                        ]
                    ],
                    [
                        '@type' => [
                            'MusicRelease',
                            'Product'
                        ],
                        '@id' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#p1271421079',
                        'name' => '12" Vinyl',
                        'additionalProperty' => [
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'item_id',
                                'value' => 1271421079
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'item_type',
                                'value' => 'p'
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'selling_band_id',
                                'value' => 1235691216
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'type_name',
                                'value' => 'Vinyl LP'
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'image_ids',
                                'value' => [
                                    1822625
                                ]
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'is_music_merch',
                                'value' => true
                            ],
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'type_id',
                                'value' => 2
                            ]
                        ],
                        'offers' => [
                            '@type' => 'Offer',
                            'url' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant#p1271421079-buy',
                            'priceCurrency' => 'EUR',
                            'price' => 12.0,
                            'priceSpecification' => [
                                'minPrice' => 12.0
                            ],
                            'availability' => 'SoldOut',
                            'additionalProperty' => [
                                [
                                    '@type' => 'PropertyValue',
                                    'name' => 'includes_digital_download',
                                    'value' => true
                                ]
                            ]
                        ],
                        'musicReleaseFormat' => 'VinylFormat',
                        'image' => [
                            'https://f4.bcbits.com/img/0001822625_10.jpg'
                        ]
                    ]
                ],
                'albumReleaseType' => 'SingleRelease',
                '@id' => 'https://jeanjean.bandcamp.com/album/symmetry',
                'additionalProperty' => [
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'download_pref',
                        'value' => 2
                    ]
                ]
            ],
            'byArtist' => [
                '@type' => 'MusicGroup',
                'name' => 'Jean Jean',
                '@id' => 'https://jeanjean.bandcamp.com'
            ],
            'publisher' => [
                '@type' => 'MusicGroup',
                '@id' => 'https://jeanjean.bandcamp.com',
                'name' => 'Jean Jean',
                'additionalProperty' => [
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'band_id',
                        'value' => 1235691216
                    ],
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'has_any_downloads',
                        'value' => true
                    ],
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'has_download_codes',
                        'value' => true
                    ],
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'image_height',
                        'value' => 1600
                    ],
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'image_id',
                        'value' => 29836714
                    ],
                    [
                        '@type' => 'PropertyValue',
                        'name' => 'image_width',
                        'value' => 2279
                    ]
                ],
                'image' => 'https://f4.bcbits.com/img/0029836714_10.jpg',
                'genre' => 'https://bandcamp.com/discover/rock',
                'description' => '« On stage, JEAN JEAN is a mirror to their music : deeply intense, smiling and sharing an outra- geous joie-de-vivre. It all seems so simple, but when it builds up, they take you far, very far away » (Christophe Ehrwein)',
                'mainEntityOfPage' => [
                    [
                        '@type' => 'WebPage',
                        'url' => 'http://www.facebook.com/jeanjeanmusic',
                        'name' => 'Facebook'
                    ],
                    [
                        '@type' => 'WebPage',
                        'url' => 'https://www.instagram.com/wearejeanjean/',
                        'name' => 'Instagram'
                    ],
                    [
                        '@type' => 'WebPage',
                        'url' => 'http://www.youtube.com/channel/UCOsMtEsuiqbqkFQ9oyqJhHg',
                        'name' => 'YouTube'
                    ],
                    [
                        '@type' => 'WebPage',
                        'url' => 'http://jeanjeanband.com/',
                        'name' => 'jeanjeanband.com'
                    ],
                    [
                        '@type' => 'WebPage',
                        'url' => 'https://twitter.com/jeanjeanband',
                        'name' => 'Twitter'
                    ]
                ],
                'subjectOf' => [
                    [
                        '@type' => 'WebPage',
                        'url' => 'https://jeanjean.bandcamp.com/music',
                        'name' => 'music',
                        'additionalProperty' => [
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'nav_type',
                                'value' => 'm'
                            ]
                        ]
                    ],
                    [
                        '@type' => 'WebPage',
                        'url' => 'https://jeanjean.bandcamp.com/merch',
                        'name' => 'merch',
                        'additionalProperty' => [
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'nav_type',
                                'value' => 'p'
                            ]
                        ]
                    ],
                    [
                        '@type' => 'WebPage',
                        'url' => 'https://jeanjean.bandcamp.com/community',
                        'name' => 'community',
                        'additionalProperty' => [
                            [
                                '@type' => 'PropertyValue',
                                'name' => 'nav_type',
                                'value' => 'c'
                            ]
                        ]
                    ]
                ],
                'foundingLocation' => [
                    '@type' => 'Place',
                    'name' => 'Sept Sorts, France'
                ]
            ],
            'copyrightNotice' => 'All Rights Reserved',
            'keywords' => [
                'Rock',
                'ambient',
                'electro-rock',
                'instrumental',
                'interstellar',
                'Sept Sorts'
            ],
            'image' => 'https://f4.bcbits.com/img/a3289609405_10.jpg',
            'sponsor' => [
                [
                    '@type' => 'Person',
                    'url' => 'https://bandcamp.com/jaredremillard',
                    'image' => 'https://f4.bcbits.com/img/0001850798_50.jpg',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'image_id',
                            'value' => 1850798
                        ]
                    ],
                    'name' => 'Jared ReMillard'
                ],
                [
                    '@type' => 'Person',
                    'url' => 'https://bandcamp.com/sheebypanda',
                    'image' => 'https://f4.bcbits.com/img/0004764347_50.jpg',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'image_id',
                            'value' => 4764347
                        ]
                    ],
                    'name' => 'SheebyPanda'
                ],
                [
                    '@type' => 'Person',
                    'url' => 'https://bandcamp.com/salvajer911',
                    'image' => 'https://f4.bcbits.com/img/0017750248_50.jpg',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'image_id',
                            'value' => 17750248
                        ]
                    ],
                    'name' => 'Guilhem Sauvage'
                ],
                [
                    '@type' => 'Person',
                    'url' => 'https://bandcamp.com/tylerthornhill',
                    'image' => 'https://f4.bcbits.com/img/0001705921_50.jpg',
                    'additionalProperty' => [
                        [
                            '@type' => 'PropertyValue',
                            'name' => 'image_id',
                            'value' => 1705921
                        ]
                    ],
                    'name' => 'Tyler Thornhill'
                ]
            ],
            'mainEntityOfPage' => 'https://jeanjean.bandcamp.com/track/coquin-l-l-phant',
            '@context' => 'https://schema.org'
        ]
    ]
];
