<?php
declare(strict_types = 1);

return [
    'authorName' => null,
    'authorUrl' => null,
    'cms' => 'mediawiki',
    'code' => null,
    'description' => 'Albert Einstein ( EYEN-styne; German: [ˈalbɛɐt ˈʔaɪnʃtaɪn] ; 14 March 1879 – 18 April 1955) was a German-born theoretical physicist who is widely held to be one of the greatest and most influential scientists of all time. Best known for developing the theory of relativity, Einstein also made important contributions to quantum mechanics, and was thus a central figure in the revolutionary reshaping of the scientific understanding of nature that modern physics accomplished in the first decades of the twentieth century. His mass–energy equivalence formula E = mc2, which arises from relativity theory, has been called "the world\'s most famous equation". He received the 1921 Nobel Prize in Physics "for his services to theoretical physics, and especially for his discovery of the law...',
    'favicon' => 'https://en.wikipedia.org/static/favicon/wikipedia.ico',
    'feeds' => [
        'https://en.wikipedia.org/w/index.php?title=Special:RecentChanges&feed=atom'
    ],
    'icon' => 'https://en.wikipedia.org/static/apple-touch/wikipedia.png',
    'image' => 'https://upload.wikimedia.org/wikipedia/commons/thumb/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg/1200px-Einstein_1921_by_F_Schmutzer_-_restoration.jpg',
    'keywords' => [],
    'language' => 'en',
    'languages' => [],
    'license' => null,
    'providerName' => 'Wikipedia',
    'providerUrl' => 'https://en.wikipedia.org',
    'publishedTime' => '2001-11-05 18:26:16',
    'redirect' => null,
    'title' => 'Albert Einstein',
    'url' => 'https://en.wikipedia.org/wiki/Albert_Einstein',
    'linkedData' => [
        '@context' => 'https://schema.org',
        '@type' => 'Article',
        'name' => 'Albert Einstein',
        'url' => 'https://en.wikipedia.org/wiki/Albert_Einstein',
        'sameAs' => 'http://www.wikidata.org/entity/Q937',
        'mainEntity' => 'http://www.wikidata.org/entity/Q937',
        'author' => [
            '@type' => 'Organization',
            'name' => 'Contributors to Wikimedia projects'
        ],
        'publisher' => [
            '@type' => 'Organization',
            'name' => 'Wikimedia Foundation, Inc.',
            'logo' => [
                '@type' => 'ImageObject',
                'url' => 'https://www.wikimedia.org/static/images/wmf-hor-googpub.png'
            ]
        ],
        'datePublished' => '2001-11-05T18:26:16Z',
        'dateModified' => '2024-06-04T23:38:54Z',
        'image' => 'https://upload.wikimedia.org/wikipedia/commons/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg',
        'headline' => 'German-born theoretical physicist; developer of the theory of relativity (1879–1955)'
    ],
    'oEmbed' => [],
    'api' => [
        'pageid' => 736,
        'ns' => 0,
        'title' => 'Albert Einstein',
        'extract' => '<p class="mw-empty-elt">



</p>

<p><b>Albert Einstein</b> (<span></span> <i title="English pronunciation respelling"><span>EYEN</span>-styne</i>; <span>German:</span> <span lang="de-Latn-fonipa">[ˈalbɛɐt<span> </span>ˈʔaɪnʃtaɪn]</span> ; 14 March 1879 – 18 April 1955) was a German-born theoretical physicist who is widely held to be one of the greatest and most influential scientists of all time. Best known for developing the theory of relativity, Einstein also made important contributions to quantum mechanics, and was thus a central figure in the revolutionary reshaping of the scientific understanding of nature that modern physics accomplished in the first decades of the twentieth century. His mass–energy equivalence formula <span><i>E</i> = <i>mc</i><sup>2</sup></span>, which arises from relativity theory, has been called "the world\'s most famous equation". He received the 1921 Nobel Prize in Physics "for his services to theoretical physics, and especially for his discovery of the law</p>...'
    ],
    'allLinkedData' => [
        [
            '@context' => 'https://schema.org',
            '@type' => 'Article',
            'name' => 'Albert Einstein',
            'url' => 'https://en.wikipedia.org/wiki/Albert_Einstein',
            'sameAs' => 'http://www.wikidata.org/entity/Q937',
            'mainEntity' => 'http://www.wikidata.org/entity/Q937',
            'author' => [
                '@type' => 'Organization',
                'name' => 'Contributors to Wikimedia projects'
            ],
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'Wikimedia Foundation, Inc.',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.wikimedia.org/static/images/wmf-hor-googpub.png'
                ]
            ],
            'datePublished' => '2001-11-05T18:26:16Z',
            'dateModified' => '2024-06-04T23:38:54Z',
            'image' => 'https://upload.wikimedia.org/wikipedia/commons/3/3e/Einstein_1921_by_F_Schmutzer_-_restoration.jpg',
            'headline' => 'German-born theoretical physicist; developer of the theory of relativity (1879–1955)'
        ]
    ]
];
